@@ -24,7 +24,7 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <libxfce4panel/xfce-panel-plugin.h>
-#include <libxfce4panel/xfce-panel-macros-46.h>
+#include <libxfce4panel/xfce-panel-convenience.h>
 
 G_BEGIN_DECLS
 
@@ -293,7 +293,7 @@ typedef GTypeModule XfcePanelTypeModule;
  **/
 #define XFCE_PANEL_PLUGIN_REGISTER_WITH_CHECK(construct_func, check_func) \
   _XFCE_PANEL_PLUGIN_REGISTER_EXTENDED (construct_func, /* foo */, \
-    if (G_LIKELY ((*check_func) (xpp_screen) == TRUE)))
+    if (G_LIKELY ((*check_func) (xpp_screen))))
 
 
 
