@@ -58,14 +58,12 @@
 #include <panel/panel-dialogs.h>
 #include <panel/panel-plugin-external.h>
 
-#define AUTOSAVE_INTERVAL   (10 * 60)
-#define MIGRATE_BIN         HELPERDIR G_DIR_SEPARATOR_S "migrate"
+#define MIGRATE_BIN HELPERDIR G_DIR_SEPARATOR_S "migrate"
 
 
 
 static void      panel_application_dispose            (GObject                *object);
 static void      panel_application_finalize           (GObject                *object);
-static gboolean  panel_application_autosave_timer     (gpointer                user_data);
 static void      panel_application_plugin_move        (GtkWidget              *item,
                                                        PanelApplication       *application);
 static gboolean  panel_application_plugin_insert      (PanelApplication       *application,
@@ -125,9 +123,6 @@ struct _PanelApplication
   /* internal list of opened dialogs */
   GSList             *dialogs;
 
-  /* autosave timer for plugins */
-  guint               autosave_timer_id;
-
   /* autohide count at application level */
   gint                autohide_block;
 
@@ -199,7 +194,6 @@ panel_application_class_init (PanelApplicationClass *klass)
 static void
 panel_application_init (PanelApplication *application)
 {
-  GdkDisplay *display;
   GError *error = NULL;
   gint configver;
 
@@ -233,25 +227,23 @@ panel_application_init (PanelApplication *application)
   /* get a factory reference so it never unloads */
   application->factory = panel_module_factory_get ();
 
-  /* start the autosave timer for plugins */
-  application->autosave_timer_id = g_timeout_add_seconds (AUTOSAVE_INTERVAL,
-      panel_application_autosave_timer, application);
-
+#ifdef GDK_WINDOWING_WAYLAND
   /* warn the user about restricted features on Wayland */
-  display = gdk_display_get_default ();
-  if (GDK_IS_WAYLAND_DISPLAY (display))
+  if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ()))
     {
       if (! gtk_layer_is_supported ())
         g_warning ("Wayland detected without layer-shell support (either because of your"
                    " compositor or because Xfce4-panel was built without this support):"
                    " Xfce4-panel might not look like a panel and many of its features will"
                    " not be available");
-      if (! gdk_wayland_display_query_registry (display, "zwlr_foreign_toplevel_manager_v1"))
+      if (! gdk_wayland_display_query_registry (gdk_display_get_default (),
+                                                "zwlr_foreign_toplevel_manager_v1"))
         g_warning ("Wayland detected without foreign-toplevel-management support (your"
                    " compositor does not seem to support it): Some Xfce4-panel features will"
                    " not work (e.g. intellihide), as well as some plugins (e.g. ShowDesktop,"
                    " Tasklist, WindowMenu)");
     }
+#endif
 }
 
 
@@ -263,12 +255,7 @@ panel_application_dispose (GObject *object)
 
   /* save plugins: xfconf_shutdown() is called via a weak ref i.e. on dispose(),
    * so this should be done here to avoid any use-after-free */
-  if (application->autosave_timer_id != 0)
-    {
-      g_source_remove (application->autosave_timer_id);
-      application->autosave_timer_id = 0;
-      panel_application_autosave_timer (application);
-    }
+  panel_application_save (application, SAVE_PLUGIN_PROVIDERS);
 
   (*G_OBJECT_CLASS (panel_application_parent_class)->dispose) (object);
 }
@@ -302,19 +289,6 @@ panel_application_finalize (GObject *object)
 
 
 
-static gboolean
-panel_application_autosave_timer (gpointer user_data)
-{
-  PanelApplication *application = PANEL_APPLICATION (user_data);
-
-  /* emit a save signal for the plugins */
-  panel_application_save (application, SAVE_PLUGIN_PROVIDERS);
-
-  return TRUE;
-}
-
-
-
 static void
 panel_application_xfconf_window_bindings (PanelApplication *application,
                                           PanelWindow      *window,
