@@ -38,8 +38,6 @@
 #include <panel/panel-item-dialog.h>
 #include <panel/panel-module-factory.h>
 
-#include <panel/panel-gdbus-exported-service.h>
-
 static void      panel_dbus_service_finalize                   (GObject                 *object);
 static void      panel_dbus_service_plugin_event_result        (XfcePanelPluginProvider *prev_provider,
                                                                 guint                    handle,
@@ -78,11 +76,6 @@ static gboolean  panel_dbus_service_terminate                  (XfcePanelExporte
 
 
 
-struct _PanelDBusServiceClass
-{
-  XfcePanelExportedServiceSkeletonClass __parent__;
-};
-
 struct _PanelDBusService
 {
   XfcePanelExportedServiceSkeleton __parent__;
@@ -110,7 +103,7 @@ static gboolean dbus_exit_restart = FALSE;
 
 
 
-G_DEFINE_TYPE (PanelDBusService, panel_dbus_service, XFCE_PANEL_TYPE_EXPORTED_SERVICE_SKELETON)
+G_DEFINE_FINAL_TYPE (PanelDBusService, panel_dbus_service, XFCE_PANEL_TYPE_EXPORTED_SERVICE_SKELETON)
 
 
 
