@@ -46,8 +46,6 @@
 #include <panel/panel-preferences-dialog-ui.h>
 #include <panel/panel-plugin-external.h>
 
-#define PREFERENCES_HELP_URL "http://www.xfce.org"
-
 
 
 static void                     panel_preferences_dialog_finalize               (GObject                *object);
@@ -135,11 +133,6 @@ enum
   OUTPUT_TITLE
 };
 
-struct _PanelPreferencesDialogClass
-{
-  GtkBuilderClass __parent__;
-};
-
 struct _PanelPreferencesDialog
 {
   GtkBuilder  __parent__;
@@ -170,7 +163,7 @@ struct _PanelPreferencesDialog
 
 
 
-G_DEFINE_TYPE (PanelPreferencesDialog, panel_preferences_dialog, GTK_TYPE_BUILDER)
+G_DEFINE_FINAL_TYPE (PanelPreferencesDialog, panel_preferences_dialog, GTK_TYPE_BUILDER)
 
 
 
@@ -494,7 +487,7 @@ panel_preferences_dialog_bindings_update (PanelPreferencesDialog *dialog)
   panel_preferences_dialog_bindings_add (dialog, "span-monitors", "active", 0);
   panel_preferences_dialog_bindings_add (dialog, "position-locked", "active", 0);
   panel_preferences_dialog_bindings_add (dialog, "autohide-behavior", "active", 0);
-  panel_preferences_dialog_bindings_add (dialog, "disable-struts", "active", 0);
+  panel_preferences_dialog_bindings_add (dialog, "enable-struts", "active", 0);
   panel_preferences_dialog_bindings_add (dialog, "size", "value", 0);
   panel_preferences_dialog_bindings_add (dialog, "nrows", "value", 0);
   panel_preferences_dialog_bindings_add (dialog, "length-adjust", "active", 0);
@@ -702,7 +695,7 @@ panel_preferences_dialog_autohide_changed (GtkComboBox            *combobox,
   panel_return_if_fail (PANEL_IS_PREFERENCES_DIALOG (dialog));
   panel_return_if_fail (PANEL_WINDOW (dialog->active));
 
-  object = gtk_builder_get_object (GTK_BUILDER (dialog), "disable-struts");
+  object = gtk_builder_get_object (GTK_BUILDER (dialog), "enable-struts");
   panel_return_if_fail (GTK_IS_WIDGET (object));
 
   /* make "don't reserve space on borders" sensitive only when autohide is disabled */
@@ -1159,6 +1152,26 @@ panel_preferences_dialog_compositing_clicked (GtkButton *button, gpointer user_d
 
 
 
+static void
+panel_preferences_dialog_panel_switch_watch (GPid pid,
+                                             gint wait_status,
+                                             gpointer user_data)
+{
+  if (! g_spawn_check_wait_status (wait_status, NULL))
+    {
+      gchar *path = g_find_program_in_path ("xfce4-panel-profiles");
+      if (path != NULL)
+        {
+          g_spawn_command_line_async (path, NULL);
+          g_free (path);
+        }
+    }
+
+  g_spawn_close_pid (pid);
+}
+
+
+
 static void
 panel_preferences_dialog_panel_switch (GtkWidget *widget, PanelPreferencesDialog *dialog)
 {
@@ -1177,7 +1190,26 @@ panel_preferences_dialog_panel_switch (GtkWidget *widget, PanelPreferencesDialog
 
   /* first try the new name of the executable, then the old */
   if (path_new)
-    g_spawn_command_line_async (path_new, NULL);
+  {
+    gchar *path_with_opts = g_strjoin (" ", path_new, "--from-panel", NULL);
+    gchar **argv;
+    GPid pid;
+
+    if (g_shell_parse_argv (path_with_opts, NULL, &argv, NULL)
+        && g_spawn_async (NULL, argv, NULL, G_SPAWN_DO_NOT_REAP_CHILD, NULL, NULL, &pid, NULL))
+      {
+        /* try with option "--from-panel" (xfce4-panel-profiles >= 1.0.11), we'll retry
+         * without option in the idle func if it fails */
+        g_child_watch_add (pid, panel_preferences_dialog_panel_switch_watch, NULL);
+      }
+    else
+      {
+        /* probably never reached, just in case */
+        g_spawn_command_line_async (path_new, NULL);
+      }
+
+    g_free (path_with_opts);
+  }
   else if (path_old)
     g_spawn_command_line_async (path_old, NULL);
 
