@@ -359,7 +359,7 @@ launcher_dialog_add_response (GtkWidget            *widget,
   GList            *list, *li;
 
   panel_return_if_fail (GTK_IS_DIALOG (widget));
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (dialog->plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (dialog->plugin));
 
   if (response_id == 1)
     {
@@ -934,7 +934,7 @@ launcher_dialog_response (GtkWidget            *widget,
   GObject *add_dialog;
 
   panel_return_if_fail (GTK_IS_DIALOG (widget));
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (dialog->plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (dialog->plugin));
   panel_return_if_fail (GTK_IS_BUILDER (dialog->builder));
 
   if (G_UNLIKELY (response_id != 1))
@@ -1042,9 +1042,7 @@ launcher_dialog_items_set_item (GtkTreeModel         *model,
 {
   const gchar *name, *comment;
   gchar       *markup;
-  GdkPixbuf   *icon = NULL;
-  const gchar *icon_name;
-  gint         w, h;
+  GIcon       *icon;
   gchar       *tooltip;
   GFile       *gfile;
 
@@ -1059,14 +1057,7 @@ launcher_dialog_items_set_item (GtkTreeModel         *model,
   else
     markup = g_markup_printf_escaped ("<b>%s</b>", name);
 
-  icon_name = garcon_menu_item_get_icon_name (item);
-  if (!xfce_str_is_empty (icon_name))
-    {
-      if (!gtk_icon_size_lookup (GTK_ICON_SIZE_DND, &w, &h))
-        w = h = 32;
-
-      icon = xfce_panel_pixbuf_from_source (icon_name, NULL, MIN (w, h));
-    }
+  icon = launcher_plugin_tooltip_icon (garcon_menu_item_get_icon_name (item));
 
   if (dialog != NULL)
     g_signal_handlers_block_by_func (G_OBJECT (model),
@@ -1180,10 +1171,9 @@ launcher_dialog_show (LauncherPlugin *plugin)
   const gchar          *binding_names[] = { "disable-tooltips", "show-label",
                                             "move-first", "arrow-position" };
 
-  panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
+  panel_return_if_fail (LAUNCHER_IS_PLUGIN (plugin));
 
   /* setup the dialog */
-  PANEL_UTILS_LINK_4UI
   builder = panel_utils_builder_new (XFCE_PANEL_PLUGIN (plugin), launcher_dialog_ui,
                                      launcher_dialog_ui_length, &window);
   if (G_UNLIKELY (builder == NULL))
