@@ -81,7 +81,8 @@ static void     pager_plugin_mode_changed                 (XfcePanelPlugin     *
 static void     pager_plugin_configure_workspace_settings (GtkWidget         *button);
 static void     pager_plugin_configure_plugin             (XfcePanelPlugin   *panel_plugin);
 static gpointer pager_plugin_get_master_plugin            (PagerPlugin       *plugin);
-static void     pager_plugin_screen_layout_changed        (PagerPlugin       *plugin);
+static void     pager_plugin_screen_layout_changed        (PagerPlugin       *plugin,
+                                                           gpointer           screen);
 static void     pager_plugin_get_preferred_width          (GtkWidget           *widget,
                                                            gint                *minimum_width,
                                                            gint                *natural_width);
@@ -299,7 +300,7 @@ pager_plugin_set_property (GObject      *object,
       plugin->miniature_view = g_value_get_boolean (value)
                                && pager_plugin_miniature_view_is_supported ();
       if (plugin->xfw_screen != NULL)
-        pager_plugin_screen_layout_changed (plugin);
+        pager_plugin_screen_layout_changed (plugin, NULL);
       break;
 
     case PROP_ROWS:
@@ -338,7 +339,7 @@ pager_plugin_set_property (GObject      *object,
               g_object_set (master_plugin, "rows", rows, NULL);
             }
           else
-            pager_plugin_screen_layout_changed (plugin);
+            pager_plugin_screen_layout_changed (plugin, NULL);
         }
       break;
 
@@ -508,14 +509,14 @@ pager_plugin_set_ratio (PagerPlugin *plugin)
       return;
     }
 
+  plugin->ratio = (gfloat) panel_screen_get_width (screen)
+                  / (gfloat) panel_screen_get_height (screen);
   if (xfw_workspace_get_state (workspace) & XFW_WORKSPACE_STATE_VIRTUAL)
     {
       GdkRectangle *rect = xfw_workspace_get_geometry (workspace);
-      plugin->ratio = (gfloat) rect->width / (gfloat) rect->height;
+      gint scale_factor = gtk_widget_get_scale_factor (GTK_WIDGET (plugin));
+      plugin->ratio *= rect->width / (panel_screen_get_width (screen) * scale_factor);
     }
-  else
-    plugin->ratio = (gfloat) panel_screen_get_width (screen)
-                    / (gfloat) panel_screen_get_height (screen);
 }
 #endif
 
@@ -548,7 +549,7 @@ pager_plugin_screen_layout_changed_idle (gpointer data)
       return TRUE;
     }
 
-  pager_plugin_screen_layout_changed (plugin);
+  pager_plugin_screen_layout_changed (plugin, NULL);
   plugin->sync_wait = TRUE;
   plugin->sync_idle_id = 0;
 
@@ -558,7 +559,8 @@ pager_plugin_screen_layout_changed_idle (gpointer data)
 
 
 static void
-pager_plugin_screen_layout_changed (PagerPlugin *plugin)
+pager_plugin_screen_layout_changed (PagerPlugin *plugin,
+                                    gpointer screen)
 {
   XfcePanelPluginMode mode;
   GtkOrientation      orientation;
@@ -568,7 +570,8 @@ pager_plugin_screen_layout_changed (PagerPlugin *plugin)
 
   /* changing workspace layout is delayed in Libwnck code, so we have to give time
    * to the master plugin request to be processed */
-  if (plugin != pager_plugin_get_master_plugin (plugin) && plugin->sync_idle_id == 0)
+  if ((plugin != pager_plugin_get_master_plugin (plugin) || screen != NULL)
+      && plugin->sync_idle_id == 0)
     {
       plugin->sync_idle_id =
         g_idle_add_full (G_PRIORITY_LOW, pager_plugin_screen_layout_changed_idle, plugin, NULL);
@@ -651,13 +654,17 @@ pager_plugin_screen_changed (GtkWidget *widget,
       manager = xfw_screen_get_workspace_manager (xfw_screen);
       plugin->workspace_group = xfw_workspace_manager_list_workspace_groups (manager)->data;
 
-      pager_plugin_screen_layout_changed (plugin);
+      pager_plugin_screen_layout_changed (plugin, NULL);
 
       screen = gdk_screen_get_default ();
       g_signal_connect_object (G_OBJECT (screen), "monitors-changed",
          G_CALLBACK (pager_plugin_screen_layout_changed), plugin, G_CONNECT_SWAPPED);
       g_signal_connect_object (G_OBJECT (screen), "size-changed",
          G_CALLBACK (pager_plugin_screen_layout_changed), plugin, G_CONNECT_SWAPPED);
+      g_signal_connect_object (G_OBJECT (xfw_screen), "window-manager-changed",
+         G_CALLBACK (pager_plugin_screen_layout_changed), plugin, G_CONNECT_SWAPPED);
+      g_signal_connect_object (G_OBJECT (plugin->workspace_group), "viewports-changed",
+         G_CALLBACK (pager_plugin_screen_layout_changed), plugin, G_CONNECT_SWAPPED);
     }
   else
     g_object_unref (xfw_screen);
@@ -794,38 +801,16 @@ pager_plugin_configure_n_workspaces_changed (XfwWorkspaceGroup *group,
                                              XfwWorkspace *workspace,
                                              GtkBuilder *builder)
 {
-  GObject       *object;
-  gdouble        upper, value;
-  XfwWorkspace  *active_ws;
-  guint          scale_factor;
-  GtkWidget     *dialog;
-  GdkRectangle  *rect;
-  GdkScreen     *screen = gdk_screen_get_default ();
+  GObject *object;
+  gdouble upper, value;
 
   panel_return_if_fail (XFW_IS_WORKSPACE_GROUP (group));
   panel_return_if_fail (GTK_IS_BUILDER (builder));
 
   object = gtk_builder_get_object (builder, "rows");
-
   upper = xfw_workspace_group_get_workspace_count (group);
-  if (upper == 1)
-    {
-      /* check if we ware in viewport mode */
-      active_ws = xfw_workspace_group_get_active_workspace (group);
-      if (xfw_workspace_get_state (active_ws) & XFW_WORKSPACE_STATE_VIRTUAL)
-        {
-          /* number of rows * number of columns */
-          dialog = GTK_WIDGET (gtk_builder_get_object (builder, "dialog"));
-          scale_factor = gdk_window_get_scale_factor (gtk_widget_get_window (dialog));
-          rect = xfw_workspace_get_geometry (active_ws);
-          upper = rect->width / (panel_screen_get_width (screen) * scale_factor)
-                  * rect->height / (panel_screen_get_height (screen) * scale_factor);
-        }
-    }
-
   value = MIN (gtk_adjustment_get_value (GTK_ADJUSTMENT (object)), upper);
-
-  g_object_set (G_OBJECT (object), "upper", upper, "value", value, NULL);
+  g_object_set (object, "upper", upper, "value", value, NULL);
 }
 
 
