@@ -60,11 +60,6 @@ static gboolean              sn_button_query_tooltip                 (GtkWidget
 
 
 
-struct _SnButtonClass
-{
-  GtkButtonClass       __parent__;
-};
-
 struct _SnButton
 {
   GtkButton            __parent__;
@@ -83,7 +78,7 @@ struct _SnButton
   guint                menu_size_allocate_idle_handler;
 };
 
-G_DEFINE_TYPE (SnButton, sn_button, GTK_TYPE_BUTTON)
+G_DEFINE_FINAL_TYPE (SnButton, sn_button, GTK_TYPE_BUTTON)
 
 
 
@@ -160,7 +155,7 @@ sn_button_init (SnButton *button)
 SnItem *
 sn_button_get_item (SnButton *button)
 {
-  g_return_val_if_fail (XFCE_IS_SN_BUTTON (button), NULL);
+  g_return_val_if_fail (SN_IS_BUTTON (button), NULL);
 
   return button->item;
 }
@@ -170,7 +165,7 @@ sn_button_get_item (SnButton *button)
 const gchar *
 sn_button_get_name (SnButton *button)
 {
-  g_return_val_if_fail (XFCE_IS_SN_BUTTON (button), NULL);
+  g_return_val_if_fail (SN_IS_BUTTON (button), NULL);
 
   return sn_item_get_name (button->item);
 }
@@ -182,10 +177,10 @@ sn_button_new (SnItem   *item,
                SnPlugin *plugin,
                SnConfig *config)
 {
-  SnButton *button = g_object_new (XFCE_TYPE_SN_BUTTON, NULL);
+  SnButton *button = g_object_new (SN_TYPE_BUTTON, NULL);
 
-  g_return_val_if_fail (XFCE_IS_SN_ITEM (item), NULL);
-  g_return_val_if_fail (XFCE_IS_SN_CONFIG (config), NULL);
+  g_return_val_if_fail (SN_IS_ITEM (item), NULL);
+  g_return_val_if_fail (SN_IS_CONFIG (config), NULL);
 
   button->item = item;
   button->plugin = plugin;
@@ -212,7 +207,7 @@ sn_button_new (SnItem   *item,
 static void
 sn_button_finalize (GObject *object)
 {
-  SnButton *button = XFCE_SN_BUTTON (object);
+  SnButton *button = SN_BUTTON (object);
 
   if (button->menu_deactivate_handler != 0)
     g_signal_handler_disconnect (button->menu, button->menu_deactivate_handler);
@@ -232,7 +227,7 @@ static void
 sn_button_menu_deactivate (GtkWidget *widget,
                            GtkMenu   *menu)
 {
-  SnButton *button = XFCE_SN_BUTTON (widget);
+  SnButton *button = SN_BUTTON (widget);
 
   if (button->menu_deactivate_handler != 0)
   {
@@ -249,7 +244,7 @@ static gboolean
 sn_button_button_press (GtkWidget      *widget,
                         GdkEventButton *event)
 {
-  SnButton *button = XFCE_SN_BUTTON (widget);
+  SnButton *button = SN_BUTTON (widget);
   gboolean  menu_is_primary;
 
   menu_is_primary = sn_config_get_menu_is_primary (button->config);
@@ -299,7 +294,7 @@ static gboolean
 sn_button_button_release (GtkWidget      *widget,
                           GdkEventButton *event)
 {
-  SnButton *button = XFCE_SN_BUTTON (widget);
+  SnButton *button = SN_BUTTON (widget);
   gboolean  menu_is_primary;
 
   /* leave if button release happens outside of systray item */
@@ -335,7 +330,7 @@ static gboolean
 sn_button_scroll_event (GtkWidget      *widget,
                         GdkEventScroll *event)
 {
-  SnButton *button = XFCE_SN_BUTTON (widget);
+  SnButton *button = SN_BUTTON (widget);
   gdouble   delta_x, delta_y;
 
   /* see reference to https://gitlab.xfce.org/xfce/xfwm4/-/issues/641 in init() */
@@ -386,7 +381,7 @@ sn_button_scroll_event (GtkWidget      *widget,
 static void
 sn_button_unrealize (GtkWidget *widget)
 {
-  SnButton *button = XFCE_SN_BUTTON (widget);
+  SnButton *button = SN_BUTTON (widget);
 
   /*
    * The button could be hidden without being destroyed, as Blueman does for example when
@@ -418,7 +413,7 @@ sn_button_menu_size_changed_idle (gpointer user_data)
 static void
 sn_button_menu_size_changed (GtkWidget *widget)
 {
-  SnButton *button = XFCE_SN_BUTTON (widget);
+  SnButton *button = SN_BUTTON (widget);
 
   /* defer gtk_menu_reposition call since it may not work in size event handler */
   if (button->menu_size_allocate_idle_handler == 0)
@@ -434,7 +429,7 @@ static void
 sn_button_menu_changed (GtkWidget *widget,
                         SnItem    *item)
 {
-  SnButton *button = XFCE_SN_BUTTON (widget);
+  SnButton *button = SN_BUTTON (widget);
 
   if (button->menu != NULL)
     {
@@ -485,7 +480,7 @@ sn_button_query_tooltip (GtkWidget  *widget,
                          GtkTooltip *tooltip,
                          gpointer    user_data)
 {
-  SnButton    *button = XFCE_SN_BUTTON (widget);
+  SnButton    *button = SN_BUTTON (widget);
   const gchar *tooltip_title;
   const gchar *tooltip_subtitle;
   gchar       *tooltip_title_escaped;
