@@ -36,21 +36,12 @@
 
 
 
-#define DEFAULT_ICON_SIZE          22
-
-
-
 static gboolean              sn_dialog_build                         (SnDialog                *dialog);
 
 static void                  sn_dialog_finalize                      (GObject                 *object);
 
 
 
-struct _SnDialogClass
-{
-  GObjectClass         __parent__;
-};
-
 struct _SnDialog
 {
   GObject              __parent__;
@@ -65,13 +56,13 @@ struct _SnDialog
   SnConfig            *config;
 };
 
-G_DEFINE_TYPE (SnDialog, sn_dialog, G_TYPE_OBJECT)
+G_DEFINE_FINAL_TYPE (SnDialog, sn_dialog, G_TYPE_OBJECT)
 
 
 
 enum
 {
-  COLUMN_PIXBUF,
+  COLUMN_ICON,
   COLUMN_TITLE,
   COLUMN_HIDDEN,
   COLUMN_TIP
@@ -141,21 +132,21 @@ sn_dialog_init (SnDialog *dialog)
 
 static void
 sn_dialog_add_item (SnDialog   *dialog,
-                    GdkPixbuf   *pixbuf,
+                    GIcon       *icon,
                     const gchar *name,
                     const gchar *title,
                     gboolean     hidden)
 {
   GtkTreeIter iter;
 
-  g_return_if_fail (XFCE_IS_SN_DIALOG (dialog));
+  g_return_if_fail (SN_IS_DIALOG (dialog));
   g_return_if_fail (GTK_IS_LIST_STORE (dialog->store));
   g_return_if_fail (name == NULL || g_utf8_validate (name, -1, NULL));
 
   /* insert in the store */
   gtk_list_store_append (GTK_LIST_STORE (dialog->store), &iter);
   gtk_list_store_set (GTK_LIST_STORE (dialog->store), &iter,
-                      COLUMN_PIXBUF,  pixbuf,
+                      COLUMN_ICON,    icon,
                       COLUMN_TITLE,   title,
                       COLUMN_HIDDEN,  hidden,
                       COLUMN_TIP,     name,
@@ -166,21 +157,21 @@ sn_dialog_add_item (SnDialog   *dialog,
 
 static void
 sn_dialog_add_legacy_item(SnDialog *dialog,
-                   GdkPixbuf *pixbuf,
+                   GIcon *icon,
                    const gchar *name,
                    const gchar *title,
                    gboolean hidden)
 {
   GtkTreeIter iter;
 
-  g_return_if_fail(XFCE_IS_SN_DIALOG(dialog));
+  g_return_if_fail(SN_IS_DIALOG(dialog));
   g_return_if_fail(GTK_IS_LIST_STORE(dialog->legacy_store));
   g_return_if_fail(name == NULL || g_utf8_validate(name, -1, NULL));
 
   /* insert in the store */
   gtk_list_store_append(GTK_LIST_STORE(dialog->legacy_store), &iter);
   gtk_list_store_set(GTK_LIST_STORE(dialog->legacy_store), &iter,
-                     COLUMN_PIXBUF, pixbuf,
+                     COLUMN_ICON, icon,
                      COLUMN_TITLE, title,
                      COLUMN_HIDDEN, hidden,
                      COLUMN_TIP, name,
@@ -196,11 +187,11 @@ sn_dialog_update_names (SnDialog *dialog)
   const gchar *name;
   const gchar *title;
   const gchar *icon_name;
-  GdkPixbuf   *pixbuf;
+  GIcon       *icon;
   guint        i;
 
-  g_return_if_fail (XFCE_IS_SN_DIALOG (dialog));
-  g_return_if_fail (XFCE_IS_SN_CONFIG (dialog->config));
+  g_return_if_fail (SN_IS_DIALOG (dialog));
+  g_return_if_fail (SN_IS_CONFIG (dialog->config));
   g_return_if_fail (GTK_IS_LIST_STORE (dialog->store));
 
   for (li = sn_config_get_known_items (dialog->config); li != NULL; li = li->next)
@@ -208,6 +199,7 @@ sn_dialog_update_names (SnDialog *dialog)
       name = li->data;
       title = name;
       icon_name = name;
+      icon = NULL;
 
       /* check if we have a better name for the application */
       for (i = 0; i < G_N_ELEMENTS (known_applications); i++)
@@ -220,14 +212,15 @@ sn_dialog_update_names (SnDialog *dialog)
             }
         }
 
-      pixbuf = xfce_panel_pixbuf_from_source (icon_name, NULL, 22);
+      if (gtk_icon_theme_has_icon (gtk_icon_theme_get_default (), icon_name))
+        icon = g_themed_icon_new (icon_name);
 
       /* insert item in the store */
-      sn_dialog_add_item (dialog, pixbuf, name, title,
+      sn_dialog_add_item (dialog, icon, name, title,
                           sn_config_is_hidden (dialog->config, name));
 
-      if (pixbuf != NULL)
-        g_object_unref (G_OBJECT (pixbuf));
+      if (icon != NULL)
+        g_object_unref (G_OBJECT (icon));
     }
 }
 
@@ -240,11 +233,11 @@ sn_dialog_update_legacy_names(SnDialog *dialog)
   const gchar *name;
   const gchar *title;
   const gchar *icon_name;
-  GdkPixbuf *pixbuf;
+  GIcon *icon;
   guint i;
 
-  g_return_if_fail(XFCE_IS_SN_DIALOG(dialog));
-  g_return_if_fail(XFCE_IS_SN_CONFIG(dialog->config));
+  g_return_if_fail(SN_IS_DIALOG(dialog));
+  g_return_if_fail(SN_IS_CONFIG(dialog->config));
   g_return_if_fail(GTK_IS_LIST_STORE(dialog->legacy_store));
 
   for (li = sn_config_get_known_legacy_items(dialog->config); li != NULL; li = li->next)
@@ -252,6 +245,7 @@ sn_dialog_update_legacy_names(SnDialog *dialog)
     name = li->data;
     title = name;
     icon_name = name;
+    icon = NULL;
 
     /* check if we have a better name for the application */
     for (i = 0; i < G_N_ELEMENTS(known_legacy_applications); i++)
@@ -264,14 +258,15 @@ sn_dialog_update_legacy_names(SnDialog *dialog)
       }
     }
 
-    pixbuf = xfce_panel_pixbuf_from_source(icon_name, NULL, 22);
+    if (gtk_icon_theme_has_icon(gtk_icon_theme_get_default(), icon_name))
+      icon = g_themed_icon_new(icon_name);
 
     /* insert item in the store */
-    sn_dialog_add_legacy_item(dialog, pixbuf, name, title,
+    sn_dialog_add_legacy_item(dialog, icon, name, title,
                        sn_config_is_legacy_hidden(dialog->config, name));
 
-    if (pixbuf != NULL)
-      g_object_unref(G_OBJECT(pixbuf));
+    if (icon != NULL)
+      g_object_unref(G_OBJECT(icon));
   }
 }
 
@@ -364,8 +359,8 @@ sn_dialog_hidden_toggled (GtkCellRendererToggle *renderer,
   gboolean     hidden;
   gchar       *name;
 
-  g_return_if_fail (XFCE_IS_SN_DIALOG (dialog));
-  g_return_if_fail (XFCE_IS_SN_CONFIG (dialog->config));
+  g_return_if_fail (SN_IS_DIALOG (dialog));
+  g_return_if_fail (SN_IS_CONFIG (dialog->config));
   g_return_if_fail (GTK_IS_LIST_STORE (dialog->store));
 
   if (gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (dialog->store), &iter, path_string))
@@ -396,8 +391,8 @@ sn_dialog_legacy_hidden_toggled (GtkCellRendererToggle *renderer,
   gboolean     hidden;
   gchar       *name;
 
-  g_return_if_fail (XFCE_IS_SN_DIALOG (dialog));
-  g_return_if_fail (XFCE_IS_SN_CONFIG (dialog->config));
+  g_return_if_fail (SN_IS_DIALOG (dialog));
+  g_return_if_fail (SN_IS_CONFIG (dialog->config));
   g_return_if_fail (GTK_IS_LIST_STORE (dialog->store));
 
   if (gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (dialog->legacy_store), &iter, path_string))
@@ -424,32 +419,32 @@ sn_dialog_swap_rows (SnDialog   *dialog,
                      GtkTreeIter *iter_prev,
                      GtkTreeIter *iter)
 {
-  GdkPixbuf *pixbuf1, *pixbuf2;
+  GIcon     *icon1, *icon2;
   gchar     *title1, *title2;
   gboolean   hidden1, hidden2;
   gchar     *tip1, *tip2;
 
-  g_return_if_fail (XFCE_IS_SN_DIALOG (dialog));
-  g_return_if_fail (XFCE_IS_SN_CONFIG (dialog->config));
+  g_return_if_fail (SN_IS_DIALOG (dialog));
+  g_return_if_fail (SN_IS_CONFIG (dialog->config));
   g_return_if_fail (GTK_IS_LIST_STORE (dialog->store));
 
   gtk_tree_model_get (GTK_TREE_MODEL (dialog->store), iter_prev,
-                      COLUMN_PIXBUF,  &pixbuf1,
+                      COLUMN_ICON,    &icon1,
                       COLUMN_TITLE,   &title1,
                       COLUMN_HIDDEN,  &hidden1,
                       COLUMN_TIP,     &tip1, -1);
   gtk_tree_model_get (GTK_TREE_MODEL (dialog->store), iter,
-                      COLUMN_PIXBUF,  &pixbuf2,
+                      COLUMN_ICON,    &icon2,
                       COLUMN_TITLE,   &title2,
                       COLUMN_HIDDEN,  &hidden2,
                       COLUMN_TIP,     &tip2, -1);
   gtk_list_store_set (GTK_LIST_STORE (dialog->store), iter_prev,
-                      COLUMN_PIXBUF,  pixbuf2,
+                      COLUMN_ICON,    icon2,
                       COLUMN_TITLE,   title2,
                       COLUMN_HIDDEN,  hidden2,
                       COLUMN_TIP,     tip2, -1);
   gtk_list_store_set (GTK_LIST_STORE (dialog->store), iter,
-                      COLUMN_PIXBUF,  pixbuf1,
+                      COLUMN_ICON,    icon1,
                       COLUMN_TITLE,   title1,
                       COLUMN_HIDDEN,  hidden1,
                       COLUMN_TIP,     tip1, -1);
@@ -465,32 +460,32 @@ sn_dialog_legacy_swap_rows(SnDialog *dialog,
                            GtkTreeIter *iter_prev,
                            GtkTreeIter *iter)
 {
-  GdkPixbuf *pixbuf1, *pixbuf2;
+  GIcon *icon1, *icon2;
   gchar *title1, *title2;
   gboolean hidden1, hidden2;
   gchar *tip1, *tip2;
 
-  g_return_if_fail(XFCE_IS_SN_DIALOG(dialog));
-  g_return_if_fail(XFCE_IS_SN_CONFIG(dialog->config));
+  g_return_if_fail(SN_IS_DIALOG(dialog));
+  g_return_if_fail(SN_IS_CONFIG(dialog->config));
   g_return_if_fail(GTK_IS_LIST_STORE(dialog->legacy_store));
 
   gtk_tree_model_get(GTK_TREE_MODEL(dialog->legacy_store), iter_prev,
-                     COLUMN_PIXBUF, &pixbuf1,
+                     COLUMN_ICON, &icon1,
                      COLUMN_TITLE, &title1,
                      COLUMN_HIDDEN, &hidden1,
                      COLUMN_TIP, &tip1, -1);
   gtk_tree_model_get(GTK_TREE_MODEL(dialog->legacy_store), iter,
-                     COLUMN_PIXBUF, &pixbuf2,
+                     COLUMN_ICON, &icon2,
                      COLUMN_TITLE, &title2,
                      COLUMN_HIDDEN, &hidden2,
                      COLUMN_TIP, &tip2, -1);
   gtk_list_store_set(GTK_LIST_STORE(dialog->legacy_store), iter_prev,
-                     COLUMN_PIXBUF, pixbuf2,
+                     COLUMN_ICON, icon2,
                      COLUMN_TITLE, title2,
                      COLUMN_HIDDEN, hidden2,
                      COLUMN_TIP, tip2, -1);
   gtk_list_store_set(GTK_LIST_STORE(dialog->legacy_store), iter,
-                     COLUMN_PIXBUF, pixbuf1,
+                     COLUMN_ICON, icon1,
                      COLUMN_TITLE, title1,
                      COLUMN_HIDDEN, hidden1,
                      COLUMN_TIP, tip1, -1);
@@ -520,7 +515,7 @@ sn_dialog_item_up_clicked (GtkWidget *button,
   GtkTreeSelection *selection;
   GtkTreeIter       iter, iter_prev, iter_tmp;
 
-  g_return_if_fail (XFCE_IS_SN_DIALOG (dialog));
+  g_return_if_fail (SN_IS_DIALOG (dialog));
   g_return_if_fail (GTK_IS_LIST_STORE (dialog->store));
 
   treeview = gtk_builder_get_object (dialog->builder, "items-treeview");
@@ -557,7 +552,7 @@ sn_dialog_legacy_item_up_clicked(GtkWidget *button,
   GtkTreeSelection *selection;
   GtkTreeIter iter, iter_prev, iter_tmp;
 
-  g_return_if_fail(XFCE_IS_SN_DIALOG(dialog));
+  g_return_if_fail(SN_IS_DIALOG(dialog));
   g_return_if_fail(GTK_IS_LIST_STORE(dialog->legacy_store));
 
   treeview = gtk_builder_get_object(dialog->builder, "legacy-items-treeview");
@@ -594,7 +589,7 @@ sn_dialog_item_down_clicked (GtkWidget *button,
   GtkTreeSelection *selection;
   GtkTreeIter       iter, iter_next;
 
-  g_return_if_fail (XFCE_IS_SN_DIALOG (dialog));
+  g_return_if_fail (SN_IS_DIALOG (dialog));
 
   treeview = gtk_builder_get_object (dialog->builder, "items-treeview");
   g_return_if_fail (GTK_IS_TREE_VIEW (treeview));
@@ -621,7 +616,7 @@ sn_dialog_legacy_item_down_clicked(GtkWidget *button,
   GtkTreeSelection *selection;
   GtkTreeIter iter, iter_next;
 
-  g_return_if_fail(XFCE_IS_SN_DIALOG(dialog));
+  g_return_if_fail(SN_IS_DIALOG(dialog));
 
   treeview = gtk_builder_get_object(dialog->builder, "legacy-items-treeview");
   g_return_if_fail(GTK_IS_TREE_VIEW(treeview));
@@ -644,7 +639,7 @@ static void
 sn_dialog_clear_clicked (GtkWidget *button,
                          SnDialog *dialog)
 {
-  g_return_if_fail (XFCE_IS_SN_DIALOG (dialog));
+  g_return_if_fail (SN_IS_DIALOG (dialog));
 
   if (xfce_dialog_confirm (GTK_WINDOW (gtk_widget_get_toplevel (button)),
                            "edit-clear", _("Clear"), NULL,
@@ -686,7 +681,7 @@ reveal_icon_size (GtkWidget  *widget,
   gboolean active;
   gint     icon_size;
 
-  g_return_if_fail (XFCE_IS_SN_DIALOG (dialog));
+  g_return_if_fail (SN_IS_DIALOG (dialog));
 
   active = gtk_switch_get_active (GTK_SWITCH (widget));
 
@@ -879,9 +874,9 @@ sn_dialog_new (SnConfig  *config,
 {
   SnDialog *dialog;
 
-  g_return_val_if_fail (XFCE_IS_SN_CONFIG (config), NULL);
+  g_return_val_if_fail (SN_IS_CONFIG (config), NULL);
 
-  dialog = g_object_new (XFCE_TYPE_SN_DIALOG, NULL);
+  dialog = g_object_new (SN_TYPE_DIALOG, NULL);
   dialog->config = config;
 
   if (sn_dialog_build (dialog))
@@ -902,7 +897,7 @@ sn_dialog_new (SnConfig  *config,
 static void
 sn_dialog_finalize (GObject *object)
 {
-  SnDialog *dialog = XFCE_SN_DIALOG (object);
+  SnDialog *dialog = SN_DIALOG (object);
 
   if (dialog->dialog != NULL)
     gtk_widget_destroy (dialog->dialog);
