@@ -24,34 +24,15 @@
 #include <common/panel-xfconf.h>
 #include <common/panel-utils.h>
 #include <common/panel-private.h>
-#include <libxfce4panel/libxfce4panel.h>
 
+#include "tasklist.h"
 #include "tasklist-widget.h"
 #include "tasklist-dialog_ui.h"
 
 
-#define HANDLE_OFFSET (0.15)
-#define HANDLE_SIZE      (4)
+#define HANDLE_SIZE (4)
 
 
-/* TODO move to header */
-GType tasklist_plugin_get_type (void) G_GNUC_CONST;
-void tasklist_plugin_register_type (XfcePanelTypeModule *type_module);
-#define XFCE_TYPE_TASKLIST_PLUGIN            (tasklist_plugin_get_type ())
-#define XFCE_TASKLIST_PLUGIN(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), XFCE_TYPE_TASKLIST_PLUGIN, TasklistPlugin))
-#define XFCE_TASKLIST_PLUGIN_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), XFCE_TYPE_TASKLIST_PLUGIN, TasklistPluginClass))
-#define XFCE_IS_TASKLIST_PLUGIN(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XFCE_TYPE_TASKLIST_PLUGIN))
-#define XFCE_IS_TASKLIST_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XFCE_TYPE_TASKLIST_PLUGIN))
-#define XFCE_TASKLIST_PLUGIN_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), XFCE_TYPE_TASKLIST_PLUGIN, TasklistPluginClass))
-
-
-typedef struct _TasklistPluginClass TasklistPluginClass;
-struct _TasklistPluginClass
-{
-  XfcePanelPluginClass __parent__;
-};
-
-typedef struct _TasklistPlugin TasklistPlugin;
 struct _TasklistPlugin
 {
   XfcePanelPlugin __parent__;
@@ -133,7 +114,7 @@ tasklist_plugin_init (TasklistPlugin *plugin)
 static void
 tasklist_plugin_construct (XfcePanelPlugin *panel_plugin)
 {
-  TasklistPlugin      *plugin = XFCE_TASKLIST_PLUGIN (panel_plugin);
+  TasklistPlugin      *plugin = TASKLIST_PLUGIN (panel_plugin);
   const PanelProperty  properties[] =
   {
     { "show-labels", G_TYPE_BOOLEAN },
@@ -173,7 +154,7 @@ static void
 tasklist_plugin_mode_changed (XfcePanelPlugin     *panel_plugin,
                               XfcePanelPluginMode  mode)
 {
-  TasklistPlugin *plugin = XFCE_TASKLIST_PLUGIN (panel_plugin);
+  TasklistPlugin *plugin = TASKLIST_PLUGIN (panel_plugin);
 
   /* set the new tasklist mode */
   xfce_tasklist_set_mode (XFCE_TASKLIST (plugin->tasklist), mode);
@@ -185,7 +166,7 @@ static gboolean
 tasklist_plugin_size_changed (XfcePanelPlugin *panel_plugin,
                               gint             size)
 {
-  TasklistPlugin *plugin = XFCE_TASKLIST_PLUGIN (panel_plugin);
+  TasklistPlugin *plugin = TASKLIST_PLUGIN (panel_plugin);
 
   /* set the tasklist size */
   xfce_tasklist_set_size (XFCE_TASKLIST (plugin->tasklist), size);
@@ -199,7 +180,7 @@ static void
 tasklist_plugin_nrows_changed (XfcePanelPlugin *panel_plugin,
                                guint            nrows)
 {
-  TasklistPlugin *plugin = XFCE_TASKLIST_PLUGIN (panel_plugin);
+  TasklistPlugin *plugin = TASKLIST_PLUGIN (panel_plugin);
 
   /* set the tasklist nrows */
   xfce_tasklist_set_nrows (XFCE_TASKLIST (plugin->tasklist), nrows);
@@ -211,7 +192,7 @@ static void
 tasklist_plugin_screen_position_changed (XfcePanelPlugin    *panel_plugin,
                                          XfceScreenPosition  position)
 {
-  TasklistPlugin *plugin = XFCE_TASKLIST_PLUGIN (panel_plugin);
+  TasklistPlugin *plugin = TASKLIST_PLUGIN (panel_plugin);
 
   /* update monitor geometry; this function is also triggered when
    * the panel is moved to another monitor during runtime */
@@ -223,13 +204,12 @@ tasklist_plugin_screen_position_changed (XfcePanelPlugin    *panel_plugin,
 static void
 tasklist_plugin_configure_plugin (XfcePanelPlugin *panel_plugin)
 {
-  TasklistPlugin *plugin = XFCE_TASKLIST_PLUGIN (panel_plugin);
+  TasklistPlugin *plugin = TASKLIST_PLUGIN (panel_plugin);
   GtkBuilder     *builder;
   GObject        *dialog;
   GObject        *object;
 
   /* setup the dialog */
-  PANEL_UTILS_LINK_4UI
   builder = panel_utils_builder_new (panel_plugin, tasklist_dialog_ui,
                                      tasklist_dialog_ui_length, &dialog);
   if (G_UNLIKELY (builder == NULL))
@@ -289,7 +269,7 @@ tasklist_plugin_handle_draw (GtkWidget      *widget,
   guint             i;
   GdkRGBA           fg_rgba;
 
-  panel_return_val_if_fail (XFCE_IS_TASKLIST_PLUGIN (plugin), FALSE);
+  panel_return_val_if_fail (TASKLIST_IS_PLUGIN (plugin), FALSE);
   panel_return_val_if_fail (plugin->handle == widget, FALSE);
 
   if (!gtk_widget_is_drawable (widget))
